#!/bin/sh
. /opt/kelvpn/sbin/kelvpn_func.sh
. /opt/kelvpn/share/KelVPNCheck.conf

CMD=$1
tun="tun0"
subnet="10.11.9.0/24"

if [ "$CMD" = "" ]; then
    log_it_error "No command selected. Availble: init, add"
    exit 2
fi

if ! ip link show "$tun" >/dev/null 2>&1; then
    log_it_error "No tun device, can't handle routes"
    exit 1
fi

tun_addr_n_net=`ip addr show $tun | grep 'inet ' | awk '{print $2;}'`
tun_gw=`echo $tun_addr_n_net | sed 's/\.[0-9]*\/[0-9]*/\.1/'`

case "$CMD" in
    init)
    log_it "Init route tables and assign on networks"

    # 1) full
    if ! ip rule show | grep -q "from $subnet lookup full"; then
      ip rule add from "$subnet" table full
      log_it_debug "Added rule full ← $subnet"
    fi

    # 2) hybrid
    if [ "$KELVPN_MODE" = "hybrid" ]; then
      grep -q '^200 hybrid' /etc/iproute2/rt_tables \
      || echo '200 hybrid' >> /etc/iproute2/rt_tables
      if ! ip rule show | grep -q "from $subnet lookup hybrid"; then
      ip rule add from "$subnet" table hybrid
      log_it_debug "Added rule hybrid ← $subnet"
      fi
    fi
    ;;
    add)
    log_it "Add routes"
	ip route add default via $tun_gw dev tun0 table full
    ;;
    del)
	log_it "Delete routes"
	ip route del default via $tun_gw dev tun0 table full
    ;;
    deinit)
	log_it "Deinit route tables"
	ip rule del from 10.11.9.0/24 table full
    ;;
esac
